CockpitAllocationTrace class final
Allocation call-stack samples for one explicitly selected VM class.
DevTools enables this expensive stream only for classes the user selects. Cockpit follows the same rule: no class is traced unless its VM class id is passed to the profiling call.
Constructors
- CockpitAllocationTrace({required String classId, required CockpitCpuProfile profile, String? className})
- CockpitAllocationTrace.fromJson(Object? value)
-
factory
Properties
- classId → String
-
final
- className → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- profile → CockpitCpuProfile
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
{bool includeRaw = true}) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited