CockpitPerformanceMemorySample class final
One process-memory sample captured during a performance interval.
timestampUs is relative to the beginning of the capture. RSS values come directly from the platform process API and include Dart, engine, native, and mapped process memory according to that platform's accounting rules.
Constructors
- CockpitPerformanceMemorySample({required int timestampUs, required int rssBytes, required int processPeakBytes})
-
const
- CockpitPerformanceMemorySample.fromJson(Object? value)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isValid → bool
-
no setter
- processPeakBytes → int
-
final
- rssBytes → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestampUs → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override